==> tool-sql-1.1.10-sources.jar: io/ciera/tool/sql/ooaofooa/instance/impl/ValueInStackFrameSetImpl.java <==
package io.ciera.tool.sql.ooaofooa.instance.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.instance.StackFrameSet;
import io.ciera.tool.sql.ooaofooa.instance.ValueInStackFrame;
import io.ciera.tool.sql.ooaofooa.instance.ValueInStackFrameSet;
import io.ciera.tool.sql.ooaofooa.instance.impl.StackFrameSetImpl;
import io.ciera.tool.sql.ooaofooa.value.ValueSet;
import io.ciera.tool.sql.ooaofooa.value.impl.ValueSetImpl;

import java.util.Arrays;
import java.util.List;


public class ValueInStackFrameSetImpl extends InstanceSet<ValueInStackFrameSet,ValueInStackFrame> implements ValueInStackFrameSet {

    // attributes
    @Override
    public void setValueInStackFrame_ID( UniqueId m_ValueInStackFrame_ID ) throws XtumlException {
        for ( ValueInStackFrame valueinstackframe : this ) valueinstackframe.setValueInStackFrame_ID( m_ValueInStackFrame_ID );
    }
    @Override
    public void setValue_ID( UniqueId ref_Value_ID ) throws XtumlException {
        for ( ValueInStackFrame valueinstackframe : this ) valueinstackframe.setValue_ID( ref_Value_ID );
    }
    @Override
    public void setStack_Frame_ID( UniqueId ref_Stack_Frame_ID ) throws XtumlException {
        for ( ValueInStackFrame valueinstackframe : this ) valueinstackframe.setStack_Frame_ID( ref_Stack_Frame_ID );
    }
    @Override
    public void setRuntimeValue_ID( UniqueId m_RuntimeValue_ID ) throws XtumlException {
        for ( ValueInStackFrame valueinstackframe : this ) valueinstackframe.setRuntimeValue_ID( m_RuntimeValue_ID );
    }


    // selections
    @Override
    public StackFrameSet R2951_StackFrame() throws XtumlException {
        StackFrameSet stackframeset = new StackFrameSetImpl();
        for ( ValueInStackFrame valueinstackframe : this ) stackframeset.add( valueinstackframe.R2951_StackFrame() );
        return stackframeset;
    }
    @Override
    public ValueSet R2978_Value() throws XtumlException {
        ValueSet valueset = new ValueSetImpl();
        for ( ValueInStackFrame valueinstackframe : this ) valueset.add( valueinstackframe.R2978_Value() );
        return valueset;
    }


    @Override
    public ValueInStackFrame nullElement() {
        return ValueInStackFrameImpl.EMPTY_VALUEINSTACKFRAME;
    }

    @Override
    public ValueInStackFrameSet emptySet() {
      return new ValueInStackFrameSetImpl();
    }

    @Override
    public ValueInStackFrameSet value() {
        return this;
    }

    @Override
    public List<ValueInStackFrame> elements() {
        return Arrays.asList(toArray(new ValueInStackFrame[0]));
    }

}

==> tool-sql-2.2.0-sources.jar: io/ciera/tool/sql/ooaofooa/instance/impl/ValueInStackFrameSetImpl.java <==
package io.ciera.tool.sql.ooaofooa.instance.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.instance.StackFrameSet;
import io.ciera.tool.sql.ooaofooa.instance.ValueInStackFrame;
import io.ciera.tool.sql.ooaofooa.instance.ValueInStackFrameSet;
import io.ciera.tool.sql.ooaofooa.instance.impl.StackFrameSetImpl;
import io.ciera.tool.sql.ooaofooa.value.ValueSet;
import io.ciera.tool.sql.ooaofooa.value.impl.ValueSetImpl;

import java.util.Arrays;
import java.util.Comparator;
import java.util.List;


public class ValueInStackFrameSetImpl extends InstanceSet<ValueInStackFrameSet,ValueInStackFrame> implements ValueInStackFrameSet {

    public ValueInStackFrameSetImpl() {
    }

    public ValueInStackFrameSetImpl(Comparator<? super ValueInStackFrame> comp) {
        super(comp);
    }

    // attributes
    @Override
    public void setStack_Frame_ID( UniqueId ref_Stack_Frame_ID ) throws XtumlException {
        for ( ValueInStackFrame valueinstackframe : this ) valueinstackframe.setStack_Frame_ID( ref_Stack_Frame_ID );
    }
    @Override
    public void setRuntimeValue_ID( UniqueId m_RuntimeValue_ID ) throws XtumlException {
        for ( ValueInStackFrame valueinstackframe : this ) valueinstackframe.setRuntimeValue_ID( m_RuntimeValue_ID );
    }
    @Override
    public void setValueInStackFrame_ID( UniqueId m_ValueInStackFrame_ID ) throws XtumlException {
        for ( ValueInStackFrame valueinstackframe : this ) valueinstackframe.setValueInStackFrame_ID( m_ValueInStackFrame_ID );
    }
    @Override
    public void setValue_ID( UniqueId ref_Value_ID ) throws XtumlException {
        for ( ValueInStackFrame valueinstackframe : this ) valueinstackframe.setValue_ID( ref_Value_ID );
    }


    // selections
    @Override
    public StackFrameSet R2951_StackFrame() throws XtumlException {
        StackFrameSet stackframeset = new StackFrameSetImpl();
        for ( ValueInStackFrame valueinstackframe : this ) stackframeset.add( valueinstackframe.R2951_StackFrame() );
        return stackframeset;
    }
    @Override
    public ValueSet R2978_Value() throws XtumlException {
        ValueSet valueset = new ValueSetImpl();
        for ( ValueInStackFrame valueinstackframe : this ) valueset.add( valueinstackframe.R2978_Value() );
        return valueset;
    }


    @Override
    public ValueInStackFrame nullElement() {
        return ValueInStackFrameImpl.EMPTY_VALUEINSTACKFRAME;
    }

    @Override
    public ValueInStackFrameSet emptySet() {
      return new ValueInStackFrameSetImpl();
    }

    @Override
    public ValueInStackFrameSet emptySet(Comparator<? super ValueInStackFrame> comp) {
      return new ValueInStackFrameSetImpl(comp);
    }

    @Override
    public ValueInStackFrameSet value() {
        return this;
    }

    @Override
    public List<ValueInStackFrame> elements() {
        return Arrays.asList(toArray(new ValueInStackFrame[0]));
    }

}
